@@ -118,7 +118,12 @@ class Monitor:
         check_times = ws['B1'].value
         error_times = ws['C1'].value
 
-        new_data_bytes = os.stat(f"{service.log_path}" + f"{self.time}").st_size
+        try:
+            new_data_bytes = os.stat(f"{service.log_path}" + f"{self.time}").st_size
+        except Exception as e:
+            log.info("发生未知错误，无法获取文件大小，请检查文件是否存在")
+            new_data_bytes = 0
+
         log.info('主监控日志文件变化前大小为{}，变化后大小为{}'.format(old_data_bytes, new_data_bytes))
 
         if new_data_bytes != old_data_bytes:
